@@ -26,7 +26,9 @@ class OrderChangeClient(HttpClient):
 
     def get(self, id_):
         """GET /air/order_changes/:id."""
-        return OrderChange.from_json(self.do_get(f"{self._url}/{id_}")["data"])
+        res = self.do_get(f"{self._url}/{id_}")
+        if res is not None:
+            return OrderChange.from_json(res["data"])
 
     def create(self, selected_order_change_offer):
         """Create a pending order change.
@@ -42,7 +44,8 @@ class OrderChangeClient(HttpClient):
             self._url,
             body={"data": {"selected_order_change_offer": selected_order_change_offer}},
         )
-        return OrderChange.from_json(res["data"])
+        if res is not None:
+            return OrderChange.from_json(res["data"])
 
     def confirm(self, id_, payment_):
         """Confirm an order change.
@@ -76,4 +79,5 @@ class OrderChangeClient(HttpClient):
                 }
             },
         )
-        return OrderChange.from_json(res["data"])
+        if res is not None:
+            return OrderChange.from_json(res["data"])
