@@ -17,6 +17,7 @@ def test_get_offer_by_id(requests_mock):
         service = offer.available_services[0]
         assert service.type == "baggage"
         assert service.total_amount == "15.00"
+        assert service.total_currency == "GBP"
 
 
 def test_get_offers(requests_mock):
@@ -40,17 +41,13 @@ def test_get_offers(requests_mock):
         assert offer.id == "off_00009htYpSCXrwaB9DnUm0"
         assert len(offer.slices) == 2
         slice_1 = offer.slices[0]
-        assert slice_1.conditions["change_before_departure"]["allowed"] is True
-        assert (
-            slice_1.conditions["change_before_departure"]["penalty_amount"] == "100.00"
-        )
-        assert (
-            slice_1.conditions["change_before_departure"]["penalty_currency"] == "GBP"
-        )
+        assert slice_1.conditions.change_before_departure.allowed is True
+        assert slice_1.conditions.change_before_departure.penalty_amount == "100.00"
+        assert slice_1.conditions.change_before_departure.penalty_currency == "GBP"
         assert len(slice_1.segments) == 1
         assert slice_1.segments[0].id == "seg_00009htYpSCXrwaB9Dn456"
         slice_2 = offer.slices[1]
-        assert slice_2.conditions["change_before_departure"] is None
+        assert slice_2.conditions.change_before_departure is None
         assert len(slice_2.segments) == 1
         assert slice_2.segments[0].id == "seg_0000AEfTff29Oo8LXf7FYG"
 
